==> plantuml-libs-9.0.0.tgz: package/distribution/aws-q2-2022/Resource/Robotics/AwsRoboMakerFleetManagement.md <==
# AwsRoboMakerFleetManagement


```text
aws-q2-2022/Resource/Robotics/AwsRoboMakerFleetManagement
```

```text
include('aws-q2-2022/Resource/Robotics/AwsRoboMakerFleetManagement')
```



| Illustration | AwsRoboMakerFleetManagement | AwsRoboMakerFleetManagementCard | AwsRoboMakerFleetManagementGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q2-2022/Resource/Robotics/AwsRoboMakerFleetManagement.png) | ![illustration for AwsRoboMakerFleetManagement](../../../aws-q2-2022/Resource/Robotics/AwsRoboMakerFleetManagement.Local.png) | ![illustration for AwsRoboMakerFleetManagementCard](../../../aws-q2-2022/Resource/Robotics/AwsRoboMakerFleetManagementCard.Local.png) | ![illustration for AwsRoboMakerFleetManagementGroup](../../../aws-q2-2022/Resource/Robotics/AwsRoboMakerFleetManagementGroup.Local.png) |




## AwsRoboMakerFleetManagement

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagement
include('aws-q2-2022/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagement('AwsRoboMakerFleetManagement', 'Aws Robo Maker Fleet Management', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagement
include('aws-q2-2022/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagement('AwsRoboMakerFleetManagement', 'Aws Robo Maker Fleet Management', 'an optional tech label')
@enduml
```

## AwsRoboMakerFleetManagementCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagementCard
include('aws-q2-2022/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagementCard('AwsRoboMakerFleetManagementCard', 'Aws Robo Maker Fleet Management Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagementCard
include('aws-q2-2022/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagementCard('AwsRoboMakerFleetManagementCard', 'Aws Robo Maker Fleet Management Card', 'an optional description')
@enduml
```

## AwsRoboMakerFleetManagementGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagementGroup
include('aws-q2-2022/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagementGroup('AwsRoboMakerFleetManagementGroup', 'Aws Robo Maker Fleet Management Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q2-2022/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagementGroup
include('aws-q2-2022/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagementGroup('AwsRoboMakerFleetManagementGroup', 'Aws Robo Maker Fleet Management Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-9.2.0.tgz: package/distribution/aws-q1-2022/Resource/Robotics/AwsRoboMakerFleetManagement.md <==
# AwsRoboMakerFleetManagement


```text
aws-q1-2022/Resource/Robotics/AwsRoboMakerFleetManagement
```

```text
include('aws-q1-2022/Resource/Robotics/AwsRoboMakerFleetManagement')
```



| Illustration | AwsRoboMakerFleetManagement | AwsRoboMakerFleetManagementCard | AwsRoboMakerFleetManagementGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q1-2022/Resource/Robotics/AwsRoboMakerFleetManagement.png) | ![illustration for AwsRoboMakerFleetManagement](../../../aws-q1-2022/Resource/Robotics/AwsRoboMakerFleetManagement.Local.png) | ![illustration for AwsRoboMakerFleetManagementCard](../../../aws-q1-2022/Resource/Robotics/AwsRoboMakerFleetManagementCard.Local.png) | ![illustration for AwsRoboMakerFleetManagementGroup](../../../aws-q1-2022/Resource/Robotics/AwsRoboMakerFleetManagementGroup.Local.png) |




## AwsRoboMakerFleetManagement

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagement
include('aws-q1-2022/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagement('AwsRoboMakerFleetManagement', 'Aws Robo Maker Fleet Management', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagement
include('aws-q1-2022/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagement('AwsRoboMakerFleetManagement', 'Aws Robo Maker Fleet Management', 'an optional tech label', 'an optional description')
@enduml
```

## AwsRoboMakerFleetManagementCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagementCard
include('aws-q1-2022/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagementCard('AwsRoboMakerFleetManagementCard', 'Aws Robo Maker Fleet Management Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagementCard
include('aws-q1-2022/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagementCard('AwsRoboMakerFleetManagementCard', 'Aws Robo Maker Fleet Management Card', 'an optional description')
@enduml
```

## AwsRoboMakerFleetManagementGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagementGroup
include('aws-q1-2022/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagementGroup('AwsRoboMakerFleetManagementGroup', 'Aws Robo Maker Fleet Management Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsRoboMakerFleetManagementGroup
include('aws-q1-2022/Resource/Robotics/AwsRoboMakerFleetManagement')

' renders the element
AwsRoboMakerFleetManagementGroup('AwsRoboMakerFleetManagementGroup', 'Aws Robo Maker Fleet Management Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
